Skip to contents

R6 class extending tlf::ExportConfiguration with row-aware height.

Details

Inherits fields and behavior from tlf::ExportConfiguration.

Inherited fields

See tlf::ExportConfiguration for name, path, format, width, height, units, and dpi.

Super class

tlf::ExportConfiguration -> ExportConfiguration

Active bindings

heightPerRow

The height of the plot dimensions for a row in a multi panel plot. The final height of the figure will be 'heightPerRow' times the number of rows. If NULL (default), value used in height is used. If not NULL, this value always overrides the height property.

Methods

Inherited methods


ExportConfiguration$savePlot()

Save/Export a plot

Usage

ExportConfiguration$savePlot(plotObject, fileName = NULL)

Arguments

plotObject

A ggplot object

fileName

character file name of the exported plot

Returns

The file name of the exported plot


ExportConfiguration$clone()

The objects of this class are cloneable with this method.

Usage

ExportConfiguration$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.