Skip to contents

Compares Excel configuration files against their JSON snapshot to determine if they are synchronized. The JSON snapshot is considered the source of truth.

Usage

projectConfigurationStatus(
  projectConfig = "ProjectConfiguration.xlsx",
  jsonPath = NULL,
  silent = FALSE,
  ignoreVersionCheck = TRUE
)

Arguments

projectConfig

A ProjectConfiguration object or path to ProjectConfiguration excel file. Defaults to "ProjectConfiguration.xlsx".

jsonPath

Path to the JSON configuration file. If NULL (default), the function will look for a JSON file with the same name as the ProjectConfiguration file but with .json extension.

silent

Logical indicating whether to suppress informational messages. Defaults to FALSE.

ignoreVersionCheck

Logical. If TRUE, the version check between the stored esqlabsR version in the configuration and the currently installed version is skipped. Defaults to TRUE because this function focuses on file synchronization status, not version compatibility.

Value

A list with components:

in_sync

Logical indicating whether all files are synchronized

details

A list with detailed comparison results for each file

unsaved_changes

Logical indicating whether the ProjectConfiguration object has unsaved modifications

See also

Other project configuration snapshots: restoreProjectConfiguration(), snapshotProjectConfiguration()