Import project configuration from JSON to Excel files
Source:R/utilities-config-json.R
restoreProjectConfiguration.RdCreates Excel configuration files from a JSON configuration file. This allows for recreating the project configuration from version-controlled JSON.
Usage
restoreProjectConfiguration(
jsonPath = "ProjectConfiguration.json",
outputDir = NULL,
silent = FALSE
)Arguments
- jsonPath
Path to the JSON configuration file. Defaults to "ProjectConfiguration.json".
- outputDir
Directory where the Excel files will be created. If NULL (default), the Excel files will be created in the same directory as the source JSON file.
- silent
Logical. If
TRUE, suppresses informational messages. Defaults toFALSE.
See also
Other project configuration snapshots:
projectConfigurationStatus(),
snapshotProjectConfiguration()