Create a default ProjectConfiguration
Source: R/utilities-project-configuration.R
createDefaultProjectConfiguration.RdCreate a ProjectConfiguration based on the
"ProjectConfiguration.xlsx"
Usage
createDefaultProjectConfiguration(
path = file.path("ProjectConfiguration.xlsx"),
ignoreVersionCheck = FALSE
)Arguments
- path
path to the
ProjectConfiguration.xlsxfile. Defaults to theProjectConfiguration.xlsxfile in the working directory.- ignoreVersionCheck
If
TRUE, skip the version mismatch check when loading the configuration file. Use this in non-interactive contexts such as automated tests or scripts running from console where interactive user input cannot be assured. Defaults toFALSE.