Creates ParameterIdentification objects from PI configurations. Each PITaskConfiguration produces one ParameterIdentification object.
Arguments
- piTaskConfigurations
Named list of
PITaskConfigurationobjects- observedData
Named list of
DataSetobjects. When provided, datasets are looked up by the name in theDataSetcolumn ofPIOutputMappings. WhenNULL(default), observed data is loaded internally using theObservedDataSheetcolumn.- stopIfParameterNotFound
Logical. If
TRUE(default), an error is thrown when a parameter defined in the scenario configuration cannot be found in the simulation. Set toFALSEto continue silently when scenario parameters are absent from the model.
Examples
if (FALSE) { # \dontrun{
projectConfiguration <- createProjectConfiguration(
exampleProjectConfigurationPath(),
ignoreVersionCheck = TRUE
)
piTaskConfigurations <- readPITaskConfigurationFromExcel(
projectConfiguration = projectConfiguration
)
piTasks <- createPITasks(piTaskConfigurations)
} # }