Create a ProjectConfiguration
Source: R/utilities-project-configuration.R
createProjectConfiguration.RdCreate a ProjectConfiguration based on the
"ProjectConfiguration.xlsx"
Usage
createProjectConfiguration(
path = file.path("ProjectConfiguration.xlsx"),
ignoreVersionCheck = FALSE
)Arguments
- path
path to the
ProjectConfiguration.xlsxfile. default to theProjectConfiguration.xlsxfile located in the working directory.- ignoreVersionCheck
If
TRUE, skip the version mismatch check when loading the configuration file. Use this in non-interactive contexts such as automated tests or scripts running from console where interactive user input cannot be assured. Defaults toFALSE.