Extend parameters structure with new entries
Source:R/utilities-parameters.R
extendParameterStructure.RdExtend parameters structure with new entries
Arguments
- parameters
A parameter structure (a list with elements
paths,values, andunits) orNULL. IfNULL, it is treated as an empty parameter structure.- newParameters
A parameter structure (a list with elements
paths,values, andunits) orNULL. IfNULL, it is treated as an empty parameter structure whose entries will be added to or overwrite those inparameters.